 /*
 * file      : src/win_scan.c
 * project   : tnt
 * with      : Gtk-3
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TNT - INDIQUEZ ICI CE QUE FAIT LE PROGRAMME
 * GNU General Public License
 *
 * This file is part of TNT.
 *
 * TNT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 *
 * TNT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TNT.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#include <gtk/gtk.h>
#include <string.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_dvbtv/lib.h"
#endif

#include "global.h"
#include "win_scan.h"
#include "win_info.h"
#include "configuser.h"
#include "chan.h"
#include "stream.h"



typedef struct {

	GtkWidget		*AdrWin;
	gboolean		IsShow;
	GtkListStore	*Adr_List_Store;

} VAR_WINSCAN;

VAR_WINSCAN	VarWinScan = { NULL, FALSE };


void winscan_open_dialog( void )
{
	GtkWidget *dialog;
	gchar *filename;

	dialog = gtk_file_chooser_dialog_new ("Open File",
										GTK_WINDOW(WindMain),
										GTK_FILE_CHOOSER_ACTION_OPEN,
										_("_Cancel"), GTK_RESPONSE_CANCEL,
										_("_Open"), GTK_RESPONSE_ACCEPT,
										NULL);

	filename = g_strdup_printf( "%s/channel.conf", Config.PathName_channel_conf );
	gtk_file_chooser_set_filename( GTK_FILE_CHOOSER(dialog), filename );
	g_free( filename );

	gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(VarWinScan.AdrWin));
	gtk_window_set_modal (GTK_WINDOW (VarWinScan.AdrWin), TRUE);
	libutils_set_default_icone_to_win( dialog );

	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
	{
		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
		g_free( Config.PathName_channel_conf );
		Config.PathName_channel_conf = g_strdup( filename );
		g_free( filename );
		gtk_button_set_label( GTK_BUTTON (GLADE_GET_OBJECT("button_path_channel_conf")), Config.PathName_channel_conf );
	}

	gtk_widget_destroy (dialog);
}
void on_button_path_channel_conf_clicked( GtkButton *button, gpointer user_data )
{
	g_print( "on_button_path_channel_conf_clicked\n" );
	winscan_open_dialog();
}

gboolean on_wind_scan_delete_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
{
	VarWinScan.IsShow = FALSE;
	gtk_widget_hide( VarWinScan.AdrWin );
	return TRUE;
}
gboolean on_wind_scan_destroy_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
{
	VarWinScan.IsShow = FALSE;
	gtk_widget_hide( VarWinScan.AdrWin) ;
	return TRUE;
}
void on_button_cancel_channel_conf_clicked( GtkButton *button, gpointer user_data )
{
	VarWinScan.IsShow = FALSE;
	gtk_widget_hide( VarWinScan.AdrWin) ;
}
void on_button_ok_channel_conf_clicked( GtkButton *button, gpointer user_data )
{
	VarWinScan.IsShow = FALSE;
	gtk_widget_hide( VarWinScan.AdrWin) ;

	gtk_list_store_clear (GTK_LIST_STORE( VarWinScan.Adr_List_Store ));
	if( FALSE == chan_read() ) {
		wininfo_create (
			WindMain,
			_("NOT FOUND channel.conf"),
			  "\n",
			_("   DVBTV will work after reading the file channel.conf   "),
			  "\n",
			"");
	}
}



void winscan_create( GtkWidget *p_WindMain, GtkListStore *p_Adr_List_Store )
{
	if( TRUE == StreamTv_is_playing() ) {
		wininfo_create (
			WindMain,
			_("Channels configuration"),
			  "\n",
			_("   You must turn off the television in order to reconfigure the channels    "),
			  "\n",
			"");
		return;
	}

	if (TRUE == VarWinScan.IsShow) {
		// gdk_window_raise (VarWinInfo.AdrWin->window);
		gdk_window_raise( gtk_widget_get_window(VarWinScan.AdrWin) );
	}
	else {
		if (NULL == VarWinScan.AdrWin) {
			VarWinScan.AdrWin = GTK_WIDGET (GLADE_GET_OBJECT("wind_scan"));
			gtk_builder_connect_signals (GtkBuilderProjet, NULL);
		}
		gtk_window_set_transient_for (GTK_WINDOW(VarWinScan.AdrWin), GTK_WINDOW(p_WindMain));
		gtk_window_set_modal (GTK_WINDOW (VarWinScan.AdrWin), TRUE);

		libutils_set_default_icone_to_win( VarWinScan.AdrWin );
		gtk_window_set_title (GTK_WINDOW(VarWinScan.AdrWin), "Scan");
		gtk_button_set_label( GTK_BUTTON (GLADE_GET_OBJECT("button_path_channel_conf")), Config.PathName_channel_conf );
		gtk_widget_show (VarWinScan.AdrWin);
	}
	VarWinScan.Adr_List_Store = p_Adr_List_Store;
	VarWinScan.IsShow = TRUE;
}
